'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_SGI_color_table'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_SGI_color_table',error_checker=_errors._error_checker)
GL_COLOR_TABLE_ALPHA_SIZE_SGI=_C('GL_COLOR_TABLE_ALPHA_SIZE_SGI',0x80DD)
GL_COLOR_TABLE_BIAS_SGI=_C('GL_COLOR_TABLE_BIAS_SGI',0x80D7)
GL_COLOR_TABLE_BLUE_SIZE_SGI=_C('GL_COLOR_TABLE_BLUE_SIZE_SGI',0x80DC)
GL_COLOR_TABLE_FORMAT_SGI=_C('GL_COLOR_TABLE_FORMAT_SGI',0x80D8)
GL_COLOR_TABLE_GREEN_SIZE_SGI=_C('GL_COLOR_TABLE_GREEN_SIZE_SGI',0x80DB)
GL_COLOR_TABLE_INTENSITY_SIZE_SGI=_C('GL_COLOR_TABLE_INTENSITY_SIZE_SGI',0x80DF)
GL_COLOR_TABLE_LUMINANCE_SIZE_SGI=_C('GL_COLOR_TABLE_LUMINANCE_SIZE_SGI',0x80DE)
GL_COLOR_TABLE_RED_SIZE_SGI=_C('GL_COLOR_TABLE_RED_SIZE_SGI',0x80DA)
GL_COLOR_TABLE_SCALE_SGI=_C('GL_COLOR_TABLE_SCALE_SGI',0x80D6)
GL_COLOR_TABLE_SGI=_C('GL_COLOR_TABLE_SGI',0x80D0)
GL_COLOR_TABLE_WIDTH_SGI=_C('GL_COLOR_TABLE_WIDTH_SGI',0x80D9)
GL_POST_COLOR_MATRIX_COLOR_TABLE_SGI=_C('GL_POST_COLOR_MATRIX_COLOR_TABLE_SGI',0x80D2)
GL_POST_CONVOLUTION_COLOR_TABLE_SGI=_C('GL_POST_CONVOLUTION_COLOR_TABLE_SGI',0x80D1)
GL_PROXY_COLOR_TABLE_SGI=_C('GL_PROXY_COLOR_TABLE_SGI',0x80D3)
GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE_SGI=_C('GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE_SGI',0x80D5)
GL_PROXY_POST_CONVOLUTION_COLOR_TABLE_SGI=_C('GL_PROXY_POST_CONVOLUTION_COLOR_TABLE_SGI',0x80D4)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glColorTableParameterfvSGI(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glColorTableParameterivSGI(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glColorTableSGI(target,internalformat,width,format,type,table):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLsizei)
def glCopyColorTableSGI(target,internalformat,x,y,width):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetColorTableParameterfvSGI(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetColorTableParameterivSGI(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glGetColorTableSGI(target,format,type,table):pass
