'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_KHR_shader_subgroup'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_KHR_shader_subgroup',error_checker=_errors._error_checker)
GL_SUBGROUP_FEATURE_ARITHMETIC_BIT_KHR=_C('GL_SUBGROUP_FEATURE_ARITHMETIC_BIT_KHR',0x00000004)
GL_SUBGROUP_FEATURE_BALLOT_BIT_KHR=_C('GL_SUBGROUP_FEATURE_BALLOT_BIT_KHR',0x00000008)
GL_SUBGROUP_FEATURE_BASIC_BIT_KHR=_C('GL_SUBGROUP_FEATURE_BASIC_BIT_KHR',0x00000001)
GL_SUBGROUP_FEATURE_CLUSTERED_BIT_KHR=_C('GL_SUBGROUP_FEATURE_CLUSTERED_BIT_KHR',0x00000040)
GL_SUBGROUP_FEATURE_QUAD_BIT_KHR=_C('GL_SUBGROUP_FEATURE_QUAD_BIT_KHR',0x00000080)
GL_SUBGROUP_FEATURE_SHUFFLE_BIT_KHR=_C('GL_SUBGROUP_FEATURE_SHUFFLE_BIT_KHR',0x00000010)
GL_SUBGROUP_FEATURE_SHUFFLE_RELATIVE_BIT_KHR=_C('GL_SUBGROUP_FEATURE_SHUFFLE_RELATIVE_BIT_KHR',0x00000020)
GL_SUBGROUP_FEATURE_VOTE_BIT_KHR=_C('GL_SUBGROUP_FEATURE_VOTE_BIT_KHR',0x00000002)
GL_SUBGROUP_QUAD_ALL_STAGES_KHR=_C('GL_SUBGROUP_QUAD_ALL_STAGES_KHR',0x9535)
GL_SUBGROUP_SIZE_KHR=_C('GL_SUBGROUP_SIZE_KHR',0x9532)
GL_SUBGROUP_SUPPORTED_FEATURES_KHR=_C('GL_SUBGROUP_SUPPORTED_FEATURES_KHR',0x9534)
GL_SUBGROUP_SUPPORTED_STAGES_KHR=_C('GL_SUBGROUP_SUPPORTED_STAGES_KHR',0x9533)

