'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_gl_spirv'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_gl_spirv',error_checker=_errors._error_checker)
GL_SHADER_BINARY_FORMAT_SPIR_V_ARB=_C('GL_SHADER_BINARY_FORMAT_SPIR_V_ARB',0x9551)
GL_SPIR_V_BINARY_ARB=_C('GL_SPIR_V_BINARY_ARB',0x9552)
@_f
@_p.types(None,_cs.GLuint,arrays.GLcharArray,_cs.GLuint,arrays.GLuintArray,arrays.GLuintArray)
def glSpecializeShaderARB(shader,pEntryPoint,numSpecializationConstants,pConstantIndex,pConstantValue):pass
