'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_ES3_2_compatibility'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_ES3_2_compatibility',error_checker=_errors._error_checker)
GL_MULTISAMPLE_LINE_WIDTH_GRANULARITY_ARB=_C('GL_MULTISAMPLE_LINE_WIDTH_GRANULARITY_ARB',0x9382)
GL_MULTISAMPLE_LINE_WIDTH_RANGE_ARB=_C('GL_MULTISAMPLE_LINE_WIDTH_RANGE_ARB',0x9381)
GL_PRIMITIVE_BOUNDING_BOX_ARB=_C('GL_PRIMITIVE_BOUNDING_BOX_ARB',0x92BE)
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glPrimitiveBoundingBoxARB(minX,minY,minZ,minW,maxX,maxY,maxZ,maxW):pass
