'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_NV_conservative_raster'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_NV_conservative_raster',error_checker=_errors._error_checker)
GL_CONSERVATIVE_RASTERIZATION_NV=_C('GL_CONSERVATIVE_RASTERIZATION_NV',0x9346)
GL_MAX_SUBPIXEL_PRECISION_BIAS_BITS_NV=_C('GL_MAX_SUBPIXEL_PRECISION_BIAS_BITS_NV',0x9349)
GL_SUBPIXEL_PRECISION_BIAS_X_BITS_NV=_C('GL_SUBPIXEL_PRECISION_BIAS_X_BITS_NV',0x9347)
GL_SUBPIXEL_PRECISION_BIAS_Y_BITS_NV=_C('GL_SUBPIXEL_PRECISION_BIAS_Y_BITS_NV',0x9348)
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint)
def glSubpixelPrecisionBiasNV(xbits,ybits):pass
