'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_semaphore'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_semaphore',error_checker=_errors._error_checker)
GL_DEVICE_UUID_EXT=_C('GL_DEVICE_UUID_EXT',0x9597)
GL_DRIVER_UUID_EXT=_C('GL_DRIVER_UUID_EXT',0x9598)
GL_LAYOUT_COLOR_ATTACHMENT_EXT=_C('GL_LAYOUT_COLOR_ATTACHMENT_EXT',0x958E)
GL_LAYOUT_DEPTH_ATTACHMENT_STENCIL_READ_ONLY_EXT=_C('GL_LAYOUT_DEPTH_ATTACHMENT_STENCIL_READ_ONLY_EXT',0x9531)
GL_LAYOUT_DEPTH_READ_ONLY_STENCIL_ATTACHMENT_EXT=_C('GL_LAYOUT_DEPTH_READ_ONLY_STENCIL_ATTACHMENT_EXT',0x9530)
GL_LAYOUT_DEPTH_STENCIL_ATTACHMENT_EXT=_C('GL_LAYOUT_DEPTH_STENCIL_ATTACHMENT_EXT',0x958F)
GL_LAYOUT_DEPTH_STENCIL_READ_ONLY_EXT=_C('GL_LAYOUT_DEPTH_STENCIL_READ_ONLY_EXT',0x9590)
GL_LAYOUT_GENERAL_EXT=_C('GL_LAYOUT_GENERAL_EXT',0x958D)
GL_LAYOUT_SHADER_READ_ONLY_EXT=_C('GL_LAYOUT_SHADER_READ_ONLY_EXT',0x9591)
GL_LAYOUT_TRANSFER_DST_EXT=_C('GL_LAYOUT_TRANSFER_DST_EXT',0x9593)
GL_LAYOUT_TRANSFER_SRC_EXT=_C('GL_LAYOUT_TRANSFER_SRC_EXT',0x9592)
GL_NUM_DEVICE_UUIDS_EXT=_C('GL_NUM_DEVICE_UUIDS_EXT',0x9596)
GL_UUID_SIZE_EXT=_C('GL_UUID_SIZE_EXT',16)
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteSemaphoresEXT(n,semaphores):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenSemaphoresEXT(n,semaphores):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuint64Array)
def glGetSemaphoreParameterui64vEXT(semaphore,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLubyteArray)
def glGetUnsignedBytei_vEXT(target,index,data):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLubyteArray)
def glGetUnsignedBytevEXT(pname,data):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsSemaphoreEXT(semaphore):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuint64Array)
def glSemaphoreParameterui64vEXT(semaphore,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,arrays.GLuintArray,_cs.GLuint,arrays.GLuintArray,arrays.GLuintArray)
def glSignalSemaphoreEXT(semaphore,numBufferBarriers,buffers,numTextureBarriers,textures,dstLayouts):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,arrays.GLuintArray,_cs.GLuint,arrays.GLuintArray,arrays.GLuintArray)
def glWaitSemaphoreEXT(semaphore,numBufferBarriers,buffers,numTextureBarriers,textures,srcLayouts):pass
