'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_window_rectangles'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_window_rectangles',error_checker=_errors._error_checker)
GL_EXCLUSIVE_EXT=_C('GL_EXCLUSIVE_EXT',0x8F11)
GL_INCLUSIVE_EXT=_C('GL_INCLUSIVE_EXT',0x8F10)
GL_MAX_WINDOW_RECTANGLES_EXT=_C('GL_MAX_WINDOW_RECTANGLES_EXT',0x8F14)
GL_NUM_WINDOW_RECTANGLES_EXT=_C('GL_NUM_WINDOW_RECTANGLES_EXT',0x8F15)
GL_WINDOW_RECTANGLE_EXT=_C('GL_WINDOW_RECTANGLE_EXT',0x8F12)
GL_WINDOW_RECTANGLE_MODE_EXT=_C('GL_WINDOW_RECTANGLE_MODE_EXT',0x8F13)
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,arrays.GLintArray)
def glWindowRectanglesEXT(mode,count,box):pass
