'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.DISABLED import _types as _cs
# End users want this...
from OpenGL.raw.DISABLED._types import *
from OpenGL.raw.DISABLED import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'DISABLED_NVX_cross_process_interop'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.DISABLED,'DISABLED_NVX_cross_process_interop',error_checker=_errors._error_checker)
GL_EXTERNAL_STORAGE_BIT_NVX=_C('GL_EXTERNAL_STORAGE_BIT_NVX',0x2000)

