'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_NV_stream_metadata'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_NV_stream_metadata',error_checker=_errors._error_checker)
EGL_CONSUMER_METADATA_NV=_C('EGL_CONSUMER_METADATA_NV',0x3254)
EGL_MAX_STREAM_METADATA_BLOCKS_NV=_C('EGL_MAX_STREAM_METADATA_BLOCKS_NV',0x3250)
EGL_MAX_STREAM_METADATA_BLOCK_SIZE_NV=_C('EGL_MAX_STREAM_METADATA_BLOCK_SIZE_NV',0x3251)
EGL_MAX_STREAM_METADATA_TOTAL_SIZE_NV=_C('EGL_MAX_STREAM_METADATA_TOTAL_SIZE_NV',0x3252)
EGL_METADATA0_SIZE_NV=_C('EGL_METADATA0_SIZE_NV',0x3255)
EGL_METADATA0_TYPE_NV=_C('EGL_METADATA0_TYPE_NV',0x3259)
EGL_METADATA1_SIZE_NV=_C('EGL_METADATA1_SIZE_NV',0x3256)
EGL_METADATA1_TYPE_NV=_C('EGL_METADATA1_TYPE_NV',0x325A)
EGL_METADATA2_SIZE_NV=_C('EGL_METADATA2_SIZE_NV',0x3257)
EGL_METADATA2_TYPE_NV=_C('EGL_METADATA2_TYPE_NV',0x325B)
EGL_METADATA3_SIZE_NV=_C('EGL_METADATA3_SIZE_NV',0x3258)
EGL_METADATA3_TYPE_NV=_C('EGL_METADATA3_TYPE_NV',0x325C)
EGL_PENDING_METADATA_NV=_C('EGL_PENDING_METADATA_NV',0x3328)
EGL_PRODUCER_METADATA_NV=_C('EGL_PRODUCER_METADATA_NV',0x3253)
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLint,arrays.EGLAttribArray)
def eglQueryDisplayAttribNV(dpy,attribute,value):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLStreamKHR,_cs.EGLenum,_cs.EGLint,_cs.EGLint,_cs.EGLint,ctypes.c_void_p)
def eglQueryStreamMetadataNV(dpy,stream,name,n,offset,size,data):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLStreamKHR,_cs.EGLint,_cs.EGLint,_cs.EGLint,ctypes.c_void_p)
def eglSetStreamMetadataNV(dpy,stream,n,offset,size,data):pass
