'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_EXT_sparse_texture'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_EXT_sparse_texture',error_checker=_errors._error_checker)
GL_MAX_SPARSE_3D_TEXTURE_SIZE_EXT=_C('GL_MAX_SPARSE_3D_TEXTURE_SIZE_EXT',0x9199)
GL_MAX_SPARSE_ARRAY_TEXTURE_LAYERS_EXT=_C('GL_MAX_SPARSE_ARRAY_TEXTURE_LAYERS_EXT',0x919A)
GL_MAX_SPARSE_TEXTURE_SIZE_EXT=_C('GL_MAX_SPARSE_TEXTURE_SIZE_EXT',0x9198)
GL_NUM_SPARSE_LEVELS_EXT=_C('GL_NUM_SPARSE_LEVELS_EXT',0x91AA)
GL_NUM_VIRTUAL_PAGE_SIZES_EXT=_C('GL_NUM_VIRTUAL_PAGE_SIZES_EXT',0x91A8)
GL_SPARSE_TEXTURE_FULL_ARRAY_CUBE_MIPMAPS_EXT=_C('GL_SPARSE_TEXTURE_FULL_ARRAY_CUBE_MIPMAPS_EXT',0x91A9)
GL_TEXTURE_2D=_C('GL_TEXTURE_2D',0x0DE1)
GL_TEXTURE_2D_ARRAY=_C('GL_TEXTURE_2D_ARRAY',0x8C1A)
GL_TEXTURE_3D=_C('GL_TEXTURE_3D',0x806F)
GL_TEXTURE_CUBE_MAP=_C('GL_TEXTURE_CUBE_MAP',0x8513)
GL_TEXTURE_CUBE_MAP_ARRAY_OES=_C('GL_TEXTURE_CUBE_MAP_ARRAY_OES',0x9009)
GL_TEXTURE_SPARSE_EXT=_C('GL_TEXTURE_SPARSE_EXT',0x91A6)
GL_VIRTUAL_PAGE_SIZE_INDEX_EXT=_C('GL_VIRTUAL_PAGE_SIZE_INDEX_EXT',0x91A7)
GL_VIRTUAL_PAGE_SIZE_X_EXT=_C('GL_VIRTUAL_PAGE_SIZE_X_EXT',0x9195)
GL_VIRTUAL_PAGE_SIZE_Y_EXT=_C('GL_VIRTUAL_PAGE_SIZE_Y_EXT',0x9196)
GL_VIRTUAL_PAGE_SIZE_Z_EXT=_C('GL_VIRTUAL_PAGE_SIZE_Z_EXT',0x9197)
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLboolean)
def glTexPageCommitmentEXT(target,level,xoffset,yoffset,zoffset,width,height,depth,commit):pass
