'''OpenGL extension EXT.device_base

This module customises the behaviour of the 
OpenGL.raw.EGL.EXT.device_base to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/device_base.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.EGL import _types, _glgets
from OpenGL.raw.EGL.EXT.device_base import *
from OpenGL.raw.EGL.EXT.device_base import _EXTENSION_NAME

def glInitDeviceBaseEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION
eglQueryDevicesEXT.extension = None 
eglQueryDevicesEXT.force_extension = True 
eglQueryDeviceStringEXT.extension = None
eglQueryDeviceStringEXT.force_extension = True 


def egl_get_devices(max_count=10):
    """Utility function that retrieves platform devices"""
    devices = (_types.EGLDeviceEXT*max_count)()
    count = _types.EGLint()
    if eglQueryDevicesEXT(max_count,devices,count):
        return devices[:count.value]
    return []
