'''OpenGL extension SGIX.ycrcb_subsample

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.ycrcb_subsample to provide a more 
Python-friendly API

Overview (from the spec)
	
	(Need to construct a real extension spec based on this)

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/ycrcb_subsample.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIX.ycrcb_subsample import *
from OpenGL.raw.GL.SGIX.ycrcb_subsample import _EXTENSION_NAME

def glInitYcrcbSubsampleSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION