'''OpenGL extension OES.stencil8

This module customises the behaviour of the 
OpenGL.raw.GLES1.OES.stencil8 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension enables 8-bit stencil component as a valid
	render buffer storage format.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/stencil8.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES1 import _types, _glgets
from OpenGL.raw.GLES1.OES.stencil8 import *
from OpenGL.raw.GLES1.OES.stencil8 import _EXTENSION_NAME

def glInitStencil8OES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION