'''OpenGL extension OES.depth24

This module customises the behaviour of the 
OpenGL.raw.GLSC2.OES.depth24 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension enables 24-bit depth components as a valid
	render buffer storage format.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/depth24.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLSC2 import _types, _glgets
from OpenGL.raw.GLSC2.OES.depth24 import *
from OpenGL.raw.GLSC2.OES.depth24 import _EXTENSION_NAME

def glInitDepth24OES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION