'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_EXT_blend_minmax'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_EXT_blend_minmax',error_checker=_errors._error_checker)
GL_BLEND_EQUATION_EXT=_C('GL_BLEND_EQUATION_EXT',0x8009)
GL_FUNC_ADD_EXT=_C('GL_FUNC_ADD_EXT',0x8006)
GL_MAX_EXT=_C('GL_MAX_EXT',0x8008)
GL_MIN_EXT=_C('GL_MIN_EXT',0x8007)
@_f
@_p.types(None,_cs.GLenum)
def glBlendEquationEXT(mode):pass
