'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_alpha_to_coverage_dither_control'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_alpha_to_coverage_dither_control',error_checker=_errors._error_checker)
GL_ALPHA_TO_COVERAGE_DITHER_DEFAULT_NV=_C('GL_ALPHA_TO_COVERAGE_DITHER_DEFAULT_NV',0x934D)
GL_ALPHA_TO_COVERAGE_DITHER_DISABLE_NV=_C('GL_ALPHA_TO_COVERAGE_DITHER_DISABLE_NV',0x934F)
GL_ALPHA_TO_COVERAGE_DITHER_ENABLE_NV=_C('GL_ALPHA_TO_COVERAGE_DITHER_ENABLE_NV',0x934E)
GL_ALPHA_TO_COVERAGE_DITHER_MODE_NV=_C('GL_ALPHA_TO_COVERAGE_DITHER_MODE_NV',0x92BF)
@_f
@_p.types(None,_cs.GLenum)
def glAlphaToCoverageDitherControlNV(mode):pass
