'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_NV_stream_consumer_gltexture_yuv'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_NV_stream_consumer_gltexture_yuv',error_checker=_errors._error_checker)
EGL_YUV_BUFFER_EXT=_C('EGL_YUV_BUFFER_EXT',0x3300)
EGL_YUV_NUMBER_OF_PLANES_EXT=_C('EGL_YUV_NUMBER_OF_PLANES_EXT',0x3311)
EGL_YUV_PLANE0_TEXTURE_UNIT_NV=_C('EGL_YUV_PLANE0_TEXTURE_UNIT_NV',0x332C)
EGL_YUV_PLANE1_TEXTURE_UNIT_NV=_C('EGL_YUV_PLANE1_TEXTURE_UNIT_NV',0x332D)
EGL_YUV_PLANE2_TEXTURE_UNIT_NV=_C('EGL_YUV_PLANE2_TEXTURE_UNIT_NV',0x332E)
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLStreamKHR,_cs.EGLAttrib)
def eglStreamConsumerGLTextureExternalAttribsNV(dpy,stream,*attrib_list):pass
