'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_EXT_clip_cull_distance'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_EXT_clip_cull_distance',error_checker=_errors._error_checker)
GL_CLIP_DISTANCE0_EXT=_C('GL_CLIP_DISTANCE0_EXT',0x3000)
GL_CLIP_DISTANCE1_EXT=_C('GL_CLIP_DISTANCE1_EXT',0x3001)
GL_CLIP_DISTANCE2_EXT=_C('GL_CLIP_DISTANCE2_EXT',0x3002)
GL_CLIP_DISTANCE3_EXT=_C('GL_CLIP_DISTANCE3_EXT',0x3003)
GL_CLIP_DISTANCE4_EXT=_C('GL_CLIP_DISTANCE4_EXT',0x3004)
GL_CLIP_DISTANCE5_EXT=_C('GL_CLIP_DISTANCE5_EXT',0x3005)
GL_CLIP_DISTANCE6_EXT=_C('GL_CLIP_DISTANCE6_EXT',0x3006)
GL_CLIP_DISTANCE7_EXT=_C('GL_CLIP_DISTANCE7_EXT',0x3007)
GL_MAX_CLIP_DISTANCES_EXT=_C('GL_MAX_CLIP_DISTANCES_EXT',0x0D32)
GL_MAX_COMBINED_CLIP_AND_CULL_DISTANCES_EXT=_C('GL_MAX_COMBINED_CLIP_AND_CULL_DISTANCES_EXT',0x82FA)
GL_MAX_CULL_DISTANCES_EXT=_C('GL_MAX_CULL_DISTANCES_EXT',0x82F9)

