'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_bindable_uniform'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_bindable_uniform',error_checker=_errors._error_checker)
GL_MAX_BINDABLE_UNIFORM_SIZE_EXT=_C('GL_MAX_BINDABLE_UNIFORM_SIZE_EXT',0x8DED)
GL_MAX_FRAGMENT_BINDABLE_UNIFORMS_EXT=_C('GL_MAX_FRAGMENT_BINDABLE_UNIFORMS_EXT',0x8DE3)
GL_MAX_GEOMETRY_BINDABLE_UNIFORMS_EXT=_C('GL_MAX_GEOMETRY_BINDABLE_UNIFORMS_EXT',0x8DE4)
GL_MAX_VERTEX_BINDABLE_UNIFORMS_EXT=_C('GL_MAX_VERTEX_BINDABLE_UNIFORMS_EXT',0x8DE2)
GL_UNIFORM_BUFFER_BINDING_EXT=_C('GL_UNIFORM_BUFFER_BINDING_EXT',0x8DEF)
GL_UNIFORM_BUFFER_EXT=_C('GL_UNIFORM_BUFFER_EXT',0x8DEE)
@_f
@_p.types(_cs.GLint,_cs.GLuint,_cs.GLint)
def glGetUniformBufferSizeEXT(program,location):pass
@_f
@_p.types(_cs.GLintptr,_cs.GLuint,_cs.GLint)
def glGetUniformOffsetEXT(program,location):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLuint)
def glUniformBufferEXT(program,location,buffer):pass
