'''OpenGL extension EXT.texture_norm16

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.texture_norm16 to provide a more 
Python-friendly API

Overview (from the spec)
	
	OpenGL ES 3.1 supports 8-bit (signed) normalized textures.
	
	This extension provides a set of new 16 bit signed normalized and
	unsigned normalized fixed point texture, renderbuffer and
	texture buffer formats.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/texture_norm16.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.texture_norm16 import *
from OpenGL.raw.GLES2.EXT.texture_norm16 import _EXTENSION_NAME

def glInitTextureNorm16EXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION