'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_NV_polygon_mode'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_NV_polygon_mode',error_checker=_errors._error_checker)
GL_FILL_NV=_C('GL_FILL_NV',0x1B02)
GL_LINE_NV=_C('GL_LINE_NV',0x1B01)
GL_POINT_NV=_C('GL_POINT_NV',0x1B00)
GL_POLYGON_MODE_NV=_C('GL_POLYGON_MODE_NV',0x0B40)
GL_POLYGON_OFFSET_LINE_NV=_C('GL_POLYGON_OFFSET_LINE_NV',0x2A02)
GL_POLYGON_OFFSET_POINT_NV=_C('GL_POLYGON_OFFSET_POINT_NV',0x2A01)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum)
def glPolygonModeNV(face,mode):pass
