'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_EXT_shader_pixel_local_storage2'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_EXT_shader_pixel_local_storage2',error_checker=_errors._error_checker)
GL_FRAMEBUFFER_INCOMPLETE_INSUFFICIENT_SHADER_COMBINED_LOCAL_STORAGE_EXT=_C('GL_FRAMEBUFFER_INCOMPLETE_INSUFFICIENT_SHADER_COMBINED_LOCAL_STORAGE_EXT',0x9652)
GL_MAX_SHADER_COMBINED_LOCAL_STORAGE_FAST_SIZE_EXT=_C('GL_MAX_SHADER_COMBINED_LOCAL_STORAGE_FAST_SIZE_EXT',0x9650)
GL_MAX_SHADER_COMBINED_LOCAL_STORAGE_SIZE_EXT=_C('GL_MAX_SHADER_COMBINED_LOCAL_STORAGE_SIZE_EXT',0x9651)
@_f
@_p.types(None,_cs.GLsizei,_cs.GLsizei,arrays.GLuintArray)
def glClearPixelLocalStorageuiEXT(offset,n,values):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei)
def glFramebufferPixelLocalStorageSizeEXT(target,size):pass
@_f
@_p.types(_cs.GLsizei,_cs.GLuint)
def glGetFramebufferPixelLocalStorageSizeEXT(target):pass
