'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NVX_linked_gpu_multicast'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NVX_linked_gpu_multicast',error_checker=_errors._error_checker)
GL_LGPU_SEPARATE_STORAGE_BIT_NVX=_C('GL_LGPU_SEPARATE_STORAGE_BIT_NVX',0x0800)
GL_MAX_LGPU_GPUS_NVX=_C('GL_MAX_LGPU_GPUS_NVX',0x92BA)
@_f
@_p.types(None,_cs.GLuint,_cs.GLbitfield,_cs.GLuint,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLuint,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei)
def glLGPUCopyImageSubDataNVX(sourceGpu,destinationGpuMask,srcName,srcTarget,srcLevel,srcX,srxY,srcZ,dstName,dstTarget,dstLevel,dstX,dstY,dstZ,width,height,depth):pass
@_f
@_p.types(None,)
def glLGPUInterlockNVX():pass
@_f
@_p.types(None,_cs.GLbitfield,_cs.GLuint,_cs.GLintptr,_cs.GLsizeiptr,ctypes.c_void_p)
def glLGPUNamedBufferSubDataNVX(gpuMask,buffer,offset,size,data):pass
