'''OpenGL extension SGIX.depth_texture

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.depth_texture to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension defines a new depth texture format.  An important
	application of depth texture images is shadow casting, but separating
	this from the shadow extension allows for the potential use of depth
	textures in other applications such as image-based rendering or
	displacement mapping.  This extension does not define new depth-texture
	environment functions, such as filtering or applying the depth values
	computed from a texture, but leaves this to other extensions, such as
	the shadow extension.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/depth_texture.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIX.depth_texture import *
from OpenGL.raw.GL.SGIX.depth_texture import _EXTENSION_NAME

def glInitDepthTextureSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION