'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_texture_cube_map'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_texture_cube_map',error_checker=_errors._error_checker)
GL_MAX_CUBE_MAP_TEXTURE_SIZE_EXT=_C('GL_MAX_CUBE_MAP_TEXTURE_SIZE_EXT',0x851C)
GL_NORMAL_MAP_EXT=_C('GL_NORMAL_MAP_EXT',0x8511)
GL_PROXY_TEXTURE_CUBE_MAP_EXT=_C('GL_PROXY_TEXTURE_CUBE_MAP_EXT',0x851B)
GL_REFLECTION_MAP_EXT=_C('GL_REFLECTION_MAP_EXT',0x8512)
GL_TEXTURE_BINDING_CUBE_MAP_EXT=_C('GL_TEXTURE_BINDING_CUBE_MAP_EXT',0x8514)
GL_TEXTURE_CUBE_MAP_EXT=_C('GL_TEXTURE_CUBE_MAP_EXT',0x8513)
GL_TEXTURE_CUBE_MAP_NEGATIVE_X_EXT=_C('GL_TEXTURE_CUBE_MAP_NEGATIVE_X_EXT',0x8516)
GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_EXT=_C('GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_EXT',0x8518)
GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_EXT=_C('GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_EXT',0x851A)
GL_TEXTURE_CUBE_MAP_POSITIVE_X_EXT=_C('GL_TEXTURE_CUBE_MAP_POSITIVE_X_EXT',0x8515)
GL_TEXTURE_CUBE_MAP_POSITIVE_Y_EXT=_C('GL_TEXTURE_CUBE_MAP_POSITIVE_Y_EXT',0x8517)
GL_TEXTURE_CUBE_MAP_POSITIVE_Z_EXT=_C('GL_TEXTURE_CUBE_MAP_POSITIVE_Z_EXT',0x8519)

