'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_NV_scissor_exclusive'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_NV_scissor_exclusive',error_checker=_errors._error_checker)
GL_SCISSOR_BOX_EXCLUSIVE_NV=_C('GL_SCISSOR_BOX_EXCLUSIVE_NV',0x9556)
GL_SCISSOR_TEST_EXCLUSIVE_NV=_C('GL_SCISSOR_TEST_EXCLUSIVE_NV',0x9555)
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLintArray)
def glScissorExclusiveArrayvNV(first,count,v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei)
def glScissorExclusiveNV(x,y,width,height):pass
