'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_parallel_shader_compile'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_parallel_shader_compile',error_checker=_errors._error_checker)
GL_COMPLETION_STATUS_ARB=_C('GL_COMPLETION_STATUS_ARB',0x91B1)
GL_MAX_SHADER_COMPILER_THREADS_ARB=_C('GL_MAX_SHADER_COMPILER_THREADS_ARB',0x91B0)
@_f
@_p.types(None,_cs.GLuint)
def glMaxShaderCompilerThreadsARB(count):pass
